@@ -3,7 +3,7 @@
 //! This parser is a simple greedy algorithm that returns result when
 //! matched successfully; try next or return error when mismatched.
 //!
-//! The [`Loader`] type can simply convert string into [`NodeBase`] type.
+//! The [`Loader`] type can simply convert string into [`Node`] type.
 //!
 //! Each pattern (the method of [`Parser`] type) is called "sub-parser",
 //! which returns a `Result<T, PError>` type, where `T` is the return type.
@@ -64,7 +64,7 @@ macro_rules! tag_prefix {
     };
 }
 
-macro_rules! err {
+macro_rules! match_or {
     ($e:expr, $then:expr) => {
         match $e {
             Ok(v) => Ok(v),
@@ -109,7 +109,7 @@ pub struct Loader<'a, R: Repr> {
     /// Parser base.
     pub parser: Parser<'a>,
     /// A visitor of anchors.
-    pub anchors: AnchorBase<R>,
+    pub anchors: Anchor<R>,
 }
 
 impl<'a, R: Repr> Loader<'a, R> {
@@ -117,7 +117,7 @@ impl<'a, R: Repr> Loader<'a, R> {
     pub fn new(doc: &'a [u8]) -> Self {
         Self {
             parser: Parser::new(doc),
-            anchors: AnchorBase::new(),
+            anchors: Anchor::new(),
         }
     }
 }
@@ -168,7 +168,7 @@ impl<R: Repr> Loader<'_, R> {
     }
 
     /// Match one doc block.
-    pub fn doc(&mut self) -> PResult<NodeBase<R>> {
+    pub fn doc(&mut self) -> PResult<Node<R>> {
         self.ind_define(0)?;
         self.forward();
         let ret = self.scalar(0, false, false)?;
@@ -194,29 +194,29 @@ impl<R: Repr> Loader<'_, R> {
     }
 
     /// Match scalar.
-    pub fn scalar(&mut self, level: usize, nest: bool, inner: bool) -> PResult<NodeBase<R>> {
+    pub fn scalar(&mut self, level: usize, nest: bool, inner: bool) -> PResult<Node<R>> {
         self.scalar_inner(|p| {
             if let Ok(s) = p.string_literal(level) {
-                Ok(YamlBase::Str(s))
+                Ok(Yaml::Str(s))
             } else if let Ok(s) = p.string_folded(level) {
-                Ok(YamlBase::Str(s))
+                Ok(Yaml::Str(s))
             } else {
-                err!(
+                match_or!(
                     p.seq(level, nest),
-                    err!(p.map(level, nest, inner), p.scalar_term(level, inner))
+                    match_or!(p.map(level, nest, inner), p.scalar_term(level, inner))
                 )
             }
         })
     }
 
     /// Match flow scalar.
-    pub fn scalar_flow(&mut self, level: usize, inner: bool) -> PResult<NodeBase<R>> {
+    pub fn scalar_flow(&mut self, level: usize, inner: bool) -> PResult<Node<R>> {
         self.scalar_inner(|p| p.scalar_term(level, inner))
     }
 
-    fn scalar_inner<F>(&mut self, f: F) -> PResult<NodeBase<R>>
+    fn scalar_inner<F>(&mut self, f: F) -> PResult<Node<R>>
     where
-        F: Fn(&mut Self) -> PResult<YamlBase<R>>,
+        F: Fn(&mut Self) -> PResult<Yaml<R>>,
     {
         let anchor = self.anchor().unwrap_or_default();
         if !anchor.is_empty() {
@@ -231,48 +231,49 @@ impl<R: Repr> Loader<'_, R> {
         let pos = self.indicator();
         let yaml = f(self)?;
         self.forward();
-        let node = NodeBase::new(yaml, pos, &tag, &anchor);
-        if !anchor.is_empty() {
-            self.anchors.insert(anchor, node.clone());
+        let node = Node::new(yaml, pos, &tag, &anchor);
+        if !anchor.is_empty() && self.anchors.insert(anchor, node.clone()).is_some() {
+            self.err("duplicated anchor definition")
+        } else {
+            Ok(node)
         }
-        Ok(node)
     }
 
     /// Match flow scalar terminal.
-    pub fn scalar_term(&mut self, level: usize, inner: bool) -> PResult<YamlBase<R>> {
+    pub fn scalar_term(&mut self, level: usize, inner: bool) -> PResult<Yaml<R>> {
         let yaml = if let Ok(s) = self.float() {
-            YamlBase::Float(s)
+            Yaml::Float(s)
         } else if let Ok(s) = self.sci_float() {
-            YamlBase::Float(s)
+            Yaml::Float(s)
         } else if let Ok(s) = self.int() {
-            YamlBase::Int(s)
+            Yaml::Int(s)
         } else if let Ok(s) = self.anchor_use() {
-            YamlBase::Anchor(s)
+            Yaml::Alias(s)
         } else if let Ok(s) = self.string_quoted(b'\'', b"''") {
-            YamlBase::Str(s)
+            Yaml::Str(s)
         } else if let Ok(s) = self.string_quoted(b'"', b"\\\"") {
-            YamlBase::Str(Parser::escape(&s))
+            Yaml::Str(Parser::escape(&s))
         } else if let Ok(s) = self.string_plain(level, inner) {
             match s.as_str() {
-                "~" | "null" | "Null" | "NULL" => YamlBase::Null,
-                "true" | "True" | "TRUE" => YamlBase::Bool(true),
-                "false" | "False" | "FALSE" => YamlBase::Bool(false),
-                ".nan" | ".NaN" | ".NAN" => YamlBase::Float("NaN".to_string()),
-                ".inf" | ".Inf" | ".INF" => YamlBase::Float("inf".to_string()),
-                "-.inf" | "-.Inf" | "-.INF" => YamlBase::Float("-inf".to_string()),
-                _ => YamlBase::Str(s),
+                "~" | "null" | "Null" | "NULL" => Yaml::Null,
+                "true" | "True" | "TRUE" => Yaml::Bool(true),
+                "false" | "False" | "FALSE" => Yaml::Bool(false),
+                ".nan" | ".NaN" | ".NAN" => Yaml::Float("NaN".to_string()),
+                ".inf" | ".Inf" | ".INF" => Yaml::Float("inf".to_string()),
+                "-.inf" | "-.Inf" | "-.INF" => Yaml::Float("-inf".to_string()),
+                _ => Yaml::Str(s),
             }
         } else {
-            err!(
+            match_or!(
                 self.seq_flow(level),
-                err!(self.map_flow(level), Ok(YamlBase::Null))
+                match_or!(self.map_flow(level), Ok(Yaml::Null))
             )?
         };
         Ok(yaml)
     }
 
     /// Match flow sequence.
-    pub fn seq_flow(&mut self, level: usize) -> PResult<YamlBase<R>> {
+    pub fn seq_flow(&mut self, level: usize) -> PResult<Yaml<R>> {
         self.sym(b'[')?;
         let mut v = vec![];
         loop {
@@ -282,7 +283,7 @@ impl<R: Repr> Loader<'_, R> {
                 break;
             }
             self.forward();
-            v.push(err!(
+            v.push(match_or!(
                 self.scalar(level + 1, false, true),
                 self.err("flow sequence item")
             )?);
@@ -298,7 +299,7 @@ impl<R: Repr> Loader<'_, R> {
     }
 
     /// Match flow map.
-    pub fn map_flow(&mut self, level: usize) -> PResult<YamlBase<R>> {
+    pub fn map_flow(&mut self, level: usize) -> PResult<Yaml<R>> {
         self.sym(b'{')?;
         let mut m = vec![];
         loop {
@@ -310,7 +311,7 @@ impl<R: Repr> Loader<'_, R> {
             self.forward();
             let k = if self.complex_mapping().is_ok() {
                 self.forward();
-                let k = err!(
+                let k = match_or!(
                     self.scalar(level + 1, false, true),
                     self.err("flow map key")
                 )?;
@@ -319,13 +320,13 @@ impl<R: Repr> Loader<'_, R> {
                 }
                 k
             } else {
-                err!(self.scalar_flow(level + 1, true), self.err("flow map key"))?
+                match_or!(self.scalar_flow(level + 1, true), self.err("flow map key"))?
             };
             if self.sym(b':').is_err() || self.bound().is_err() {
                 return self.err("flow map splitter");
             }
             self.forward();
-            let v = err!(
+            let v = match_or!(
                 self.scalar(level + 1, false, true),
                 self.err("flow map value")
             )?;
@@ -341,7 +342,7 @@ impl<R: Repr> Loader<'_, R> {
     }
 
     /// Match sequence.
-    pub fn seq(&mut self, level: usize, nest: bool) -> PResult<YamlBase<R>> {
+    pub fn seq(&mut self, level: usize, nest: bool) -> PResult<Yaml<R>> {
         let mut v = vec![];
         loop {
             self.forward();
@@ -365,7 +366,7 @@ impl<R: Repr> Loader<'_, R> {
                     break;
                 }
                 if let Ok(b) = self.unind(level) {
-                    downgrade = b
+                    downgrade = b;
                 } else {
                     break;
                 }
@@ -374,7 +375,7 @@ impl<R: Repr> Loader<'_, R> {
                 }
             }
             self.forward();
-            v.push(err!(
+            v.push(match_or!(
                 self.scalar(if downgrade { level } else { level + 1 }, false, false),
                 self.err("sequence item")
             )?);
@@ -385,7 +386,7 @@ impl<R: Repr> Loader<'_, R> {
     }
 
     /// Match map.
-    pub fn map(&mut self, level: usize, nest: bool, inner: bool) -> PResult<YamlBase<R>> {
+    pub fn map(&mut self, level: usize, nest: bool, inner: bool) -> PResult<Yaml<R>> {
         let mut m = vec![];
         loop {
             self.forward();
@@ -401,7 +402,7 @@ impl<R: Repr> Loader<'_, R> {
                 self.forward();
                 let k = if self.complex_mapping().is_ok() {
                     self.forward();
-                    let k = err!(self.scalar(level + 1, true, inner), self.err("map key"))?;
+                    let k = match_or!(self.scalar(level + 1, true, inner), self.err("map key"))?;
                     if self.gap(true).is_ok() {
                         self.ind(level)?;
                     }
@@ -424,13 +425,13 @@ impl<R: Repr> Loader<'_, R> {
                 self.forward();
                 let k = if self.complex_mapping().is_ok() {
                     self.forward();
-                    let k = err!(self.scalar(level + 1, true, inner), self.err("map key"))?;
+                    let k = match_or!(self.scalar(level + 1, true, inner), self.err("map key"))?;
                     if self.gap(true).is_ok() {
                         self.ind(level)?;
                     }
                     k
                 } else {
-                    err!(self.scalar_flow(level + 1, inner), self.err("map key"))?
+                    match_or!(self.scalar_flow(level + 1, inner), self.err("map key"))?
                 };
                 if self.sym(b':').is_err() || self.bound().is_err() {
                     return self.err("map splitter");
@@ -438,7 +439,7 @@ impl<R: Repr> Loader<'_, R> {
                 k
             };
             self.forward();
-            let v = err!(self.scalar(level + 1, true, false), self.err("map value"))?;
+            let v = match_or!(self.scalar(level + 1, true, false), self.err("map value"))?;
             m.push((k, v));
         }
         // Keep last wrapping
@@ -474,23 +475,23 @@ impl<R: Repr> DerefMut for Loader<'_, R> {
 /// age: 46
 /// ";
 /// // Node with Rc repr
-/// let (n, anchors) = parse(doc).unwrap();
+/// let (root, anchors) = parse(doc).unwrap();
 /// assert_eq!(anchors.len(), 0);
-/// assert_eq!(n, vec![node!({
+/// assert_eq!(root, vec![node!({
 ///     "name" => "Bob",
 ///     "married" => true,
 ///     "age" => 46,
 /// })]);
 /// // Node with Arc repr
-/// let (n, anchors) = parse(doc).unwrap();
+/// let (root, anchors) = parse(doc).unwrap();
 /// assert_eq!(anchors.len(), 0);
-/// assert_eq!(n, vec![node!(arc{
+/// assert_eq!(root, vec![node!(arc{
 ///     "name" => "Bob",
 ///     "married" => true,
 ///     "age" => 46,
 /// })]);
 /// ```
-pub fn parse<R: Repr>(doc: &str) -> Result<(Seq<R>, AnchorBase<R>), String> {
+pub fn parse<R: Repr>(doc: &str) -> Result<(Seq<R>, Anchor<R>), String> {
     let mut p = Loader::new(doc.as_bytes());
     p.parse()
         .map_err(|e| e.into_error(doc))
