@@ -8,11 +8,10 @@ fn show_err<E>(e: String) -> E {
 #[test]
 fn test_json() {
     const DOC: &str = include_str!("json_compatibility.json");
-    let (ans, anchors) = parse(DOC).unwrap_or_else(show_err);
-    assert_eq!(anchors.len(), 0);
-    assert_eq!(anchor_visit(&ans[0]), anchors);
+    let (mut root, anchors) = parse(DOC).unwrap_or_else(show_err);
+    let node = root.remove(0);
     assert_eq!(
-        ans[0],
+        node,
         node!({
             "a" => "b",
             "c" => node!([123, 321, 1234567]),
@@ -20,29 +19,28 @@ fn test_json() {
             "e:f" => "g"
         })
     );
-    let n = ans[0].get("a").unwrap();
+    assert_eq!(anchors.len(), 0);
+    assert_eq!(Anchor::from(node.clone()), anchors);
+    let n = node.get("a").unwrap();
     assert_eq!(n, &node!("b"));
 }
 
 #[test]
 fn test_yaml() {
     const DOC: &str = include_str!("complete_doc.yaml");
-    let (ans, anchors) = parse(DOC).unwrap_or_else(show_err);
-    assert_eq!(anchors.len(), 2);
-    assert!(anchors.contains_key("x"));
-    assert!(anchors.contains_key("y"));
-    assert_eq!(anchor_visit(&ans[0]), anchors);
+    let (mut root, anchors) = parse(DOC).unwrap_or_else(show_err);
+    let node = root.remove(0);
     assert_eq!(
-        ans[0],
+        node,
         node!({
             "a0 bb" => ".val.",
             "::a1" => node!({
                 "b1" => 4.,
                 "b2" => node!([
                     "50%",
-                    node!(YamlBase::Float("2e-4".to_string())),
-                    node!(YamlBase::Float("NaN".to_string())),
-                    node!(YamlBase::Float("-inf".to_string())),
+                    node!(Yaml::Float("2e-4".to_string())),
+                    node!(Yaml::Float("NaN".to_string())),
+                    node!(Yaml::Float("-inf".to_string())),
                     "-.infs",
                     "2001-11-23 15:01:42 -5",
                 ]),
@@ -72,12 +70,16 @@ fn test_yaml() {
             ]),
         })
     );
+    assert_eq!(anchors.len(), 2);
+    assert!(anchors.contains_key("x"));
+    assert!(anchors.contains_key("y"));
+    assert_eq!(Anchor::from(node.clone()), anchors);
     let k = node!("a0 bb");
-    assert_eq!(ans[0][k].tag(), "tag:test.x.prefix:foo");
+    assert_eq!(node[k].tag(), "tag:test.x.prefix:foo");
     let k = node!("-a2");
-    assert_eq!(ans[0][k].tag(), "tag:test.prefix:t1");
+    assert_eq!(node[k].tag(), "tag:test.prefix:t1");
     let k = node!("?a3");
-    assert_eq!(ans[0][k].tag(), "tag:my.tag.prefix:tt");
+    assert_eq!(node[k].tag(), "tag:my.tag.prefix:tt");
 }
 
 #[test]
@@ -100,9 +102,11 @@ fn test_dump() {
 #[test]
 fn test_indent() {
     const DOC: &str = include_str!("indent.yaml");
-    let (ans, _) = parse(DOC).unwrap_or_else(show_err);
+    let (mut root, _) = parse(DOC).unwrap_or_else(show_err);
+    let node1 = root.remove(0);
+    let node2 = root.remove(0);
     assert_eq!(
-        ans[0],
+        node1,
         node!({
             "version" => 2,
             "models" => node!([node!({
@@ -112,7 +116,28 @@ fn test_indent() {
                     "tests" => node!(["not_null"]),
                 })]),
             })]),
+            "map" => node!(["a", "b", "c"]),
         })
     );
-    assert_eq!(ans[1], node!(["a1", "true of", "a2"]));
+    assert_eq!(node2, node!(["a1", "true of", "a2"]));
+}
+
+#[test]
+fn test_anchor() {
+    const DOC: &str = include_str!("anchor.yaml");
+    let (mut root, mut anchor) = parse::<repr::RcRepr>(DOC).unwrap_or_else(show_err);
+    anchor.resolve(1).unwrap();
+    let node = root.remove(0).replace_anchor(&anchor).unwrap();
+    std::mem::drop(anchor);
+    assert_eq!(
+        node,
+        node!([
+            node!({"a" => "b"}),
+            node!({"a" => "b"}),
+            node!({"a" => "b"}),
+            node!({"a" => "b"}),
+            node!([node!({"a" => "b"}), node!({"a" => "b"})]),
+            node!([node!({"a" => "b"}), node!({"a" => "b"})]),
+        ])
+    );
 }
